History
=======

2.0a4 (2015-11-09)
------------------

- Add ``-p``/``-V`` options to display properties and values that can be guessed.


2.0a3 (2015-11-08)
------------------

- Allow rebulk customization in API module.

2.0a2 (2015-11-07)
------------------

- Raise TypeError instead of AssertionError when non text is given to guessit API.
- Fix packaging issues with previous release blocking installation.

2.0a1 (2015-11-07)
------------------

- Rewrite from scratch using `Rebulk <https://www.github.com/Toilal/rebulk>`_
- Read `MIGRATION.rst <https://github.com/wackou/guessit/blob/2.x/MIGRATION.rst>`_ for migration guidelines.
